PlotParValues: Plot HYPE model parameter values.

View source: R/function_PlotParValues.R

PlotParValuesR Documentation

Plot HYPE model parameter values.

Description

Plot parameter values for HYPE par.txt files.

Usage

PlotParValues(
  par,
  ignore_parameters = NULL,
  n_plots = 1,
  col.values = NULL,
  file = NULL,
  width = NULL,
  height = NULL
)

Arguments

par

A HYPE par.txt file read in with ReadPar or a named list of par.txt files read in with ReadPar. E.g. par <- list("par_1" = par1, "par2" = par2).

ignore_parameters

A list containing HYPE parameter names that should be ignored while plotting. E.g. ignore_pars <- c("par1", "par2").

n_plots

Integer, if greater than 1, then the HYPE parameters will be split among n plots. Useful if plotting many parameters.

col.values

A list containing color values to set custom colors. Length of col.values should match length of par. See ggplot2::scale_color_manual.

file

Optional filename used to save plot(s) to file. See ggplot2::ggsave.

width

Width in inches for output plot. See ggplot2::ggsave.

height

Height in inches for output plot. See ggplot2::ggsave.

Details

PlotParValues generates a set of faceted boxplots to show the parameter values for a given HYPE par.txt file or list of par.txt files. The plots can be used to compare parameter values between models.

Value

Returns an list of plot objects

Examples

par <- ReadPar(
  system.file(
    "demo_model", "par.txt",
    package = "HYPEtools"
  )
)
PlotParValues(par)


HYPEtools documentation built on April 9, 2026, 1:07 a.m.