- map
Path to file containing subbasin polygon GIS data (e.g. shapefile or geopackage) or a SpatialPolygonsDataFrame
or sf object. For large maps, a small/simplified polygon file should be used as larger files can take an excessive amount of time to render.
- map.subid.column
Integer, column index in the map 'data' slot holding SUBIDs (sub-catchment IDs).
Only required if providing GeoData information with gd.
- gd
Path to model GeoData.txt or a GeoData object from ReadGeoData. Only required if map does not contain SUBID and/or MAINDOWN fields.
- bd
Path to model BranchData.txt or a BranchData object from ReadBranchData. Only required if model has a BranchData.txt file.
- filter.map.subids
Logical, if TRUE, then SUBIDs in map which are not present in gd will not be added to the map.
Otherwise, all SUBIDs in map will be added to the map.
- plot.scale
Logical, include a scale bar on the map.
- plot.searchbar
Logical, if TRUE, then a search bar will be included. See leaflet.extras::addSearchFeatures().
- weight
Numeric, weight of subbasin boundary lines. See leaflet::addPolygons().
- opacity
Numeric, opacity of subbasin boundary lines. See leaflet::addPolygons().
- fillColor
String, color of subbasin polygons. See leaflet::addPolygons().
- fillOpacity
Numeric, opacity of subbasin polygons. See leaflet::addPolygons().
- line.color
String, color codes to use for each routing line. If NULL, then random colors will be used. If a single value is provided, then that color will be used for all lines.
A data frame with "SUBID" and "COLOR" columns can also be entered to provide specific colors for each SUBID (See Example #2).
- line.weight
Numeric, weight of routing lines. See leaflet::addPolylines().If a single value is provided, then that weight will be used for all lines.
A data frame with "SUBID" and "WEIGHT" columns can also be entered to provide specific weights for each SUBID (See Example #2).
- line.opacity
Numeric, opacity of routing lines. See leaflet::addPolylines().
- seed
Integer, seed number to to produce repeatable color palette.
- darken
Numeric specifying the amount of darkening applied to the random color palette. Negative values will lighten the palette. See distinctColorPalette.
- font.size
Numeric, font size (px) for map subbasin labels.
- file
Save map to an image file by specifying the path to the desired output file using this argument. File extension must be specified.
See mapview::mapshot().
You may need to run webshot::install_phantomjs() the first time you save a map to an image file.
- vwidth
Numeric, width of the exported map image in pixels. See webshot::webshot().
- vheight
Numeric, height of the exported map image in pixels. See webshot::webshot().
- html.name
Save map to an interactive HTML file by specifying the path to the desired output file using this argument. File extension must be specified.
See htmlwidgets::saveWidget().