RunHYPE is a wrapper to run a HYPE model using a specified HYPE executable.
RunHYPE(hype.path = NULL, info.dir = NULL, sequence = 0, p = FALSE, ...)Output messages from the HYPE executable are printed to the console.
Path to HYPE .exe executable (Windows) or HYPE file on Linux
Optional path to a separate directory containing the HYPE model setup (info.txt, GeoData.txt, etc.). If not specified, then the directory of hype.path will be used.
Optional integer between 0 and 999 specifying which forcing files to use.
Optional logical. If TRUE, then the sequence number will also be applied to the parameter file. Ignored if FALSE (default).
Additional arguments passed on to system.
RunHYPE is a system wrapper to run a HYPE model via the system console. HYPE executables can be downloaded from the official code repository.
The path to the HYPE executable must be specified with hype.path. If your HYPE model is saved to a different directory than the HYPE executable (hype.path), then you can
specify the model directory with info.dir. The sequence argument can be used to specify which forcing files should be used for the simulation,
and p can be used to specify if the sequence number should also be applied to the parameter file.
Read more about how to run HYPE on the HYPE wiki.