ScalePar applies a user-specified scaling factor, timestep.ratio, to all time scale-dependent parameters and recession coefficients
in a HYPE parameter list. Parameters are matched against an inbuilt set of parameter names. To see these parameters, call ScalePar(print.par = TRUE).
Please notify us if you find any missing parameters.
If parameters are not timestep-dependent recession coefficients, then scaling is performed using the ratio between the two time step lengths (e.g. 1/24 when scaling from daily to hourly time steps).
If parameters are timestep-dependent recession coefficients, then scaling is performed using the relationship described in:
Nalbantis, Ioannis (1995). “Use of multiple-time-step information in rainfall-runoff modelling”, Journal of Hydrology 165, 1-4, pp. 135–159.
new_parameter_value = 1 - (1 - old_parameter_value)^time_step_ratio
ScalePar does not scale the values for the "gratk", "ilratk", "olratk", or "wetrate" rating curve parameters in par.txt because they are not limited to the range 0-1.
Likewise, HYPEtools does not provide any scaling function for the "RATE" columns in DamData.txt and LakeData.txt because these values are not limited to the range 0-1.
We recommend looking at the results from the lakes/wetlands and recalibrating these parameters and their related power coefficients as needed.
Use the ScaleAquiferData and ScaleFloodData functions to scale the time-dependent recession coefficients in AquiferData.txt and FloodData.txt files, respectively.