View source: R/function_LakeDataOutlets.R
| LakeDataOutlets | R Documentation |
Identifies the SUBID(s) corresponding to the outlet of each lake in a LakeData data frame.
LakeDataOutlets(ld, gd)
ld |
A data frame containing LakeData information (i.e. an imported 'LakeData.txt' file).
Must contain the columns |
gd |
A data frame containing GeoData information used to determine the upstream connectivity between SUBIDs (i.e. an imported 'GeoData.txt' file). |
A SUBID is identified as a lake outlet when all SUBIDs belonging to
the same lake occur in the upstream area of that SUBID. The function
uses AllUpstreamSubids() to determine the upstream SUBIDs.
An integer vector containing the SUBIDs identified as lake outlets. One or more SUBIDs may be returned for a lake if the lake contains multiple downstream outlets.
AllUpstreamSubids()
ld <- ReadLakeData(
filename = system.file("demo_model", "LakeData.txt", package = "HYPEtools")
)
gd <- ReadGeoData(
filename = system.file("demo_model", "GeoData.txt", package = "HYPEtools")
)
LakeDataOutlets(ld, gd)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.