View source: R/function_PlotParValues.R
| PlotParValues | R Documentation |
Plot parameter values for HYPE par.txt files.
PlotParValues(
par,
ignore_parameters = NULL,
n_plots = 1,
col.values = NULL,
file = NULL,
width = NULL,
height = NULL
)
par |
A HYPE par.txt file read in with |
ignore_parameters |
A list containing HYPE parameter names that should be ignored while plotting. E.g. |
n_plots |
Integer, if greater than 1, then the HYPE parameters will be split among n plots. Useful if plotting many parameters. |
col.values |
A list containing color values to set custom colors. Length of |
file |
Optional filename used to save plot(s) to file. See ggplot2::ggsave. |
width |
Width in inches for output plot. See ggplot2::ggsave. |
height |
Height in inches for output plot. See ggplot2::ggsave. |
PlotParValues generates a set of faceted boxplots to show the parameter values for a given HYPE par.txt file or list of par.txt files. The plots can be used to
compare parameter values between models.
Returns an list of plot objects
par <- ReadPar(
system.file(
"demo_model", "par.txt",
package = "HYPEtools"
)
)
PlotParValues(par)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.