powered by
Plot parameter values for HYPE par.txt files.
PlotParValues( par, geom.type = c("boxplot", "violin", "dotplot", "point"), ignore_parameters = NULL, n_plots = 1, col.values = NULL, file = NULL, width = NULL, height = NULL )
Returns an list of plot objects
A HYPE par.txt file read in with ReadPar or a named list of par.txt files read in with ReadPar. E.g. par <- list("par_1" = par1, "par2" = par2).
ReadPar
par <- list("par_1" = par1, "par2" = par2)
String indicating the geometry type used to generate the plots. One of boxplot, violin, dotplot, or point.
boxplot
violin
dotplot
point
A list containing HYPE parameter names that should be ignored while plotting. E.g. ignore_pars <- c("par1", "par2").
ignore_pars <- c("par1", "par2")
Integer, if greater than 1, then the HYPE parameters will be split among n plots. Useful if plotting many parameters.
A list containing color values to set custom colors. Length of col.values should match length of par. See ggplot2::scale_color_manual.
col.values
par
Optional filename used to save plot(s) to file. See ggplot2::ggsave.
Width in inches for output plot. See ggplot2::ggsave.
Height in inches for output plot. See ggplot2::ggsave.
PlotParValues generates a set of faceted plots to show the parameter values for a given HYPE par.txt file or list of par.txt files. The plots can be used to compare parameter values between models.
PlotParValues
if (FALSE) { par <- ReadPar( system.file( "demo_model", "par.txt", package = "HYPEtools" ) ) PlotParValues(par) }
Run the code above in your browser using DataLab